Index: pkg/front_end/tool/perf.dart |
diff --git a/pkg/analyzer_cli/tool/perf.dart b/pkg/front_end/tool/perf.dart |
similarity index 98% |
copy from pkg/analyzer_cli/tool/perf.dart |
copy to pkg/front_end/tool/perf.dart |
index 40a747ab1e27e473bb416b1f1b48c6ff7dc63293..d56012e6529e8f68b4f3e72664c5adac4280b900 100644 |
--- a/pkg/analyzer_cli/tool/perf.dart |
+++ b/pkg/front_end/tool/perf.dart |
@@ -2,8 +2,8 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-/// An entrypoint used to run portions of analyzer and measure its performance. |
-library analyzer_cli.tool.perf; |
+/// An entrypoint used to run portions of front_end and measure its performance. |
+library front_end.tool.perf; |
import 'dart:async'; |
import 'dart:io' show exit; |